Coordinator

Struct Coordinator 

pub struct Coordinator<T: NodeType, N, S> {
Show 26 fields membership_coordinator: EpochMembershipCoordinator<T>, consensus: Consensus<T>, network: N, state_manager: StateManager<T>, client: CoordinatorClient<T>, vid_disperser: VidDisperser<T>, vid_reconstructor: VidReconstructor<T>, vote1_collector: VoteCollector<T, QuorumVote2<T>, QuorumCertificate2<T>>, vote2_collector: VoteCollector<T, Vote2<T>, Certificate2<T>>, timeout_collector: VoteCollector<T, TimeoutVote2<T>, TimeoutCertificate2<T>>, timeout_one_honest_collector: VoteCollector<T, TimeoutVote2<T>, TimeoutOneHonest<T>>, checkpoint_collector: VoteCollector<T, CheckpointVote<T>, CheckpointCertificate<T>>, epoch_root_collector: EpochRootVoteCollector<T>, epoch_manager: EpochManager<T>, block_builder: BlockBuilder<T>, proposal_validator: ProposalValidator<T>, share_validator: VidShareValidator<T>, storage: Storage<T, S>, outbox: Outbox<ConsensusOutput<T>>, coordinator_outbox: Outbox<CoordinatorOutput<T>>, public_key: T::SignatureKey, node_id: KeyPrefix, timer: Timer, pending_proposal_fetches: PendingProposalFetches<T>, cached_validated_proposals: BTreeMap<ViewNumber, ValidatedProposal<T>>, cached_vid_shares: BTreeMap<ViewNumber, VidDisperseShare2<T>>,
}

Fields

membership_coordinator: EpochMembershipCoordinator<T>consensus: Consensus<T>network: Nstate_manager: StateManager<T>client: CoordinatorClient<T>vid_disperser: VidDisperser<T>vid_reconstructor: VidReconstructor<T>vote1_collector: VoteCollector<T, QuorumVote2<T>, QuorumCertificate2<T>>vote2_collector: VoteCollector<T, Vote2<T>, Certificate2<T>>timeout_collector: VoteCollector<T, TimeoutVote2<T>, TimeoutCertificate2<T>>timeout_one_honest_collector: VoteCollector<T, TimeoutVote2<T>, TimeoutOneHonest<T>>checkpoint_collector: VoteCollector<T, CheckpointVote<T>, CheckpointCertificate<T>>epoch_root_collector: EpochRootVoteCollector<T>epoch_manager: EpochManager<T>block_builder: BlockBuilder<T>proposal_validator: ProposalValidator<T>share_validator: VidShareValidator<T>storage: Storage<T, S>outbox: Outbox<ConsensusOutput<T>>coordinator_outbox: Outbox<CoordinatorOutput<T>>public_key: T::SignatureKeynode_id: KeyPrefixtimer: Timerpending_proposal_fetches: PendingProposalFetches<T>cached_validated_proposals: BTreeMap<ViewNumber, ValidatedProposal<T>>cached_vid_shares: BTreeMap<ViewNumber, VidDisperseShare2<T>>

Implementations

Source

impl<T: NodeType, N, S> Coordinator<T, N, S>

pub fn builder() -> CoordinatorBuilder<T, N, S>

Create an instance of Coordinator using the builder syntax

Source

impl<T, N, S> Coordinator<T, N, S>
where T: NodeType, N: Network<T>, S: NewProtocolStorage<T>,

pub fn start(&mut self)

Emit ViewChanged(current_view + 1) and, if leader, a RequestBlockAndHeader.

fn resume_after_cutover_tc(&mut self)

Kick the leader after the seed lands when a forwarded TC2 had already advanced current_view. No-op unless leader and all prerequisites are present.

pub async fn stop(self)

pub async fn next_consensus_input( &mut self, ) -> Result<ConsensusInput<T>, CoordinatorError>

pub fn apply_consensus(&mut self, input: ConsensusInput<T>)

pub fn process_consensus_output( &mut self, output: ConsensusOutput<T>, ) -> Result<(), CoordinatorError>

pub fn node_id(&self) -> &KeyPrefix

pub fn outbox(&self) -> &Outbox<ConsensusOutput<T>>

pub fn outbox_mut(&mut self) -> &mut Outbox<ConsensusOutput<T>>

pub fn coordinator_outbox(&self) -> &Outbox<CoordinatorOutput<T>>

pub fn coordinator_outbox_mut(&mut self) -> &mut Outbox<CoordinatorOutput<T>>

pub fn current_view(&self) -> ViewNumber

pub fn state(&self, v: ViewNumber) -> Option<&StateEntry<T>>

pub fn client_api(&self) -> &ClientApi<T>

pub(crate) async fn on_network_message( &mut self, message: Message<T, Unchecked>, ) -> Option<ConsensusInput<T>>

fn on_state_manager_output( &mut self, output: StateManagerOutput<T>, ) -> Option<ConsensusInput<T>>

fn on_proposal_and_vid_share( &mut self, validated: ValidatedProposal<T>, vid_share: VidDisperseShare2<T>, ) -> Result<ConsensusInput<T>, CoordinatorError>

fn unicast_to_leader( &mut self, view: ViewNumber, epoch: EpochNumber, msg: BlockMessage<T>, ) -> Result<(), CoordinatorError>

fn leader( &mut self, view: ViewNumber, epoch: EpochNumber, ) -> Option<T::SignatureKey>

async fn on_client_request( &mut self, request: ClientRequest<T>, ) -> Result<(), CoordinatorError>

fn gc(&mut self, view: ViewNumber, epoch: EpochNumber)

pub fn maker<'f1>() -> CoordinatorMaker<'f1, T, N, S>